@@ -20,6 +20,7 @@ def get_data_file(filename):
 def octofludbHome():
     return os.path.join(os.path.expanduser("~"), ".octofludb")
 
+
 def getDatadir(config):
     datadir = expandpath(config["datadir"])[0]
     if not os.path.exists(datadir):
@@ -27,6 +28,21 @@ def getDatadir(config):
     return datadir
 
 
+def error_log_entry(entries, logfile):
+    homedir = octofludbHome()
+    logdir = os.path.join(homedir, "logs")
+    logpath = os.path.join(logdir, logfile)
+
+    if not os.path.exists(logdir):
+        os.mkdir(logdir)
+
+    with open(logpath, "a") as f:
+        for line in entries:
+            print(line, file=f)
+
+    return logpath
+
+
 def epiflu_fasta_files(config):
     try:
         data_home = getDataDir(config)
