@@ -4,6 +4,7 @@ import signal
 import sys
 import os
 from octofludb.util import log, die
+from octofludb.version import __version__
 
 
 def open_graph():
@@ -28,9 +29,9 @@ def with_graph(f, *args, filename=None, outfile=sys.stdout, **kwargs):
     log("done")
     for l in turtles.splitlines():
         try:
-          print(l.decode("utf-8"), file=outfile)
+            print(l.decode("utf-8"), file=outfile)
         except:
-          print(l, file=outfile)
+            print(l, file=outfile)
     g.close()
 
 
@@ -308,14 +309,6 @@ def upload_motifs(config, url, repo):
         prep_table(h3_motif_table, outfile=turtleout)
     upload(["h3-motifs.ttl"], url=url, repo=repo)
 
-    # load all tags
-    for (tag, basename) in config["tags"].items():
-        for filename in script.tag_files(config, tag):
-            outfile = filename + ".ttl"
-            with open(outfile, "w") as f:
-                prep_tag(tag, filename, outfile=f)
-            upload([outfile], url=url, repo=repo)
-
 
 @click.command(
     name="pull",
@@ -329,9 +322,6 @@ def upload_motifs(config, url, repo):
 @click.option(
     "--no-schema", is_flag=True, default=False, help="Skip upload schema steps"
 )
-@click.option(
-    "--include-gisaid", is_flag=True, default=False, help="include gisaid data step"
-)
 @click.option(
     "--no-clades",
     is_flag=True,
@@ -347,10 +337,27 @@ def upload_motifs(config, url, repo):
 @click.option(
     "--no-motifs", is_flag=True, default=False, help="Skip motif extraction steps"
 )
+@click.option(
+    "--include-gisaid", is_flag=True, default=False, help="include gisaid data step"
+)
+@click.option(
+    "--include-tags",
+    is_flag=True,
+    default=False,
+    help="Upload tags as defined in the config file",
+)
 @url_opt
 @repo_name_opt
 def pull_cmd(
-    nmonths, no_schema, include_gisaid, no_clades, no_subtype, no_motifs, url, repo
+    nmonths,
+    no_schema,
+    no_clades,
+    no_subtype,
+    no_motifs,
+    include_gisaid,
+    include_tags,
+    url,
+    repo,
 ):
     """
     Update data. Pull from genbank, process any new data in the data folder,
@@ -399,6 +406,15 @@ def pull_cmd(
     if not no_motifs:
         upload_motifs(config, url, repo)
 
+    if include_tags:
+        # load all tags
+        for (tag, basename) in config["tags"].items():
+            for filename in script.tag_files(config, tag):
+                outfile = filename + ".ttl"
+                with open(outfile, "w") as f:
+                    prep_tag(tag, filename, outfile=f)
+                upload([outfile], url=url, repo=repo)
+
     os.chdir(cwd)
 
     return None
@@ -623,13 +639,22 @@ def prep_gis_cmd(filename):
 def _mk_gbids_cmd(g, gbids=[]):
     import octofludb.entrez as entrez
     import octofludb.genbank as gb
+    import octofludb.script as script
+
+    error_msgs = []
 
     for gb_metas in entrez.get_gbs(gbids):
         for gb_meta in gb_metas:
-            gb.add_gb_meta_triples(g, gb_meta)
+            error_msg = gb.add_gb_meta_triples(g, gb_meta)
+            if error_msg:
+                error_msgs.append(error_msg)
         # commit the current batch (say of 1000 entries)
         g.commit()
 
+    if len(error_msgs) > 0:
+        logpath = script.error_log_entry(error_msgs, "failed_genbank_parses.txt")
+        log(f"{len(error_msgs)} genbank entries could not be parsed, see {logpath}")
+
 
 @click.command(
     name="gbids",
@@ -686,7 +711,7 @@ def prep_update_gb(minyear, maxyear, nmonths):
     ):
         if missing_acc:
             outfile = ".gb_" + date.replace("/", "-") + ".ttl"
-            if os.path.exists(outfile):
+            if os.path.exists(outfile) and os.path.getsize(outfile) > 0:
                 log(f"GenBank turtle file for '{str(date)}' already exists, skipping")
             else:
                 log(colors.good(f"Updating {date} ..."))
@@ -881,7 +906,7 @@ def prep_unpublished_cmd(filename, tag, delimiter, include, exclude, na):
     """
     import octofludb.recipes as recipe
 
-    def _mk_unpublisehd_fasta_cmd(g, fh):
+    def _mk_unpublished_fasta_cmd(g, fh):
         (inc, exc, levels) = process_tablelike(include, exclude, None)
         recipe.IrregularFasta(
             filehandle=fh,
@@ -893,7 +918,7 @@ def prep_unpublished_cmd(filename, tag, delimiter, include, exclude, na):
             na_str=make_na(na),
         ).connect(g)
 
-    with_graph(_mk_unpublisehd_fasta_cmd, filename)
+    with_graph(_mk_unpublished_fasta_cmd, filename=filename)
 
 
 @click.group(
@@ -1346,6 +1371,7 @@ delete_grp.add_command(delete_motifs_cmd)
 
 
 @click.group(cls=OrderedGroup, context_settings=CONTEXT_SETTINGS)
+@click.version_option(__version__, "-v", "--version", message=__version__)
 def cli_grp():
     """
     API and utilities for the USDA swine IVA surveillance database
